#! /usr/bin/env python
# -*- coding: utf-8 -*-


import logging
logger = logging.getLogger(__name__)
# import funkcí z jiného adresáře
# import sys
import os.path
import os.path as op
# import copy

import unittest
from nose.plugins.attrib import attr
# sample_data_path = os.path.dirname(os.path.abspath(__file__))
# sample_data_path
# sys.path.append(os.path.join(path_to_script, "../extern/pyseg_base/src/"))
# sys.path.append(os.path.join(path_to_script, "../extern/py3DSeedEditor/"))
# sys.path.append(os.path.join(path_to_script, "../src/"))

from PyQt4.QtGui import QFileDialog, QApplication, QMainWindow
import sys

import numpy as np

try:
    import dicom as pydicom
    pydicom.debug(False)
except:
    import pydicom

#
import io3d
import io3d.dcmreaddata as dcmr
import io3d.fsbrowser
sample_data_path = "~/data/medical/orig/sample_data/"
sample_data_path = op.expanduser(sample_data_path)

class FileSystemBrowserTest(unittest.TestCase):

    @unittest.skip('waiting for implementation')
    def test_fsbrowser(self):

        # TODO make test stronger
        filepath = pydicom.data.get_testdata_files('DICOMDIR')[0]
        fsb = io3d.fsbrowser.FileSystemBrowser(filepath)
        dirlist = fsb.list_directory()
        self.assertTrue("path" in dirlist[0])
        self.assertTrue("name" in dirlist[0])


if __name__ == "__main__":
    unittest.main()



#! /usr/bin/env python
# -*- coding: utf-8 -*-

# import funkcí z jiného adresáře
import os.path

import unittest

import numpy as np
import os

import io3d

class ImageManipulationTest(unittest.TestCase):
    interactivetTest = False
    # interactivetTest = True


    def test_resize_to_shape(self):

        data = np.random.rand(3, 4, 5)
        new_shape = [5, 6, 6]
        data_out = io3d.misc.resize_to_shape(data, new_shape)
        # print data_out.shape
        # print data
        # print data_out
        self.assertEquals(new_shape[0], data_out.shape[0])
        self.assertEquals(new_shape[1], data_out.shape[1])
        self.assertEquals(new_shape[2], data_out.shape[2])

    def test_resize_to_mm(self):

        data = np.random.rand(3, 4, 6)
        voxelsize_mm = [2, 3, 1]
        new_voxelsize_mm = [1, 3, 2]
        expected_shape = [6, 4, 3]
        data_out = io3d.misc.resize_to_mm(data, voxelsize_mm, new_voxelsize_mm)
        # print(data_out.shape)
        # print data
        # print data_out
        self.assertEquals(expected_shape[0], data_out.shape[0])
        self.assertEquals(expected_shape[1], data_out.shape[1])
        self.assertEquals(expected_shape[2], data_out.shape[2])

if __name__ == "__main__":
    unittest.main()
